@@ -58,8 +58,14 @@ class JWTVerifier(BaseVerifier):
             
     def get_public_key(self, kid, unverified):
         host, version = unverified['iss'].split('/')
+        env = host.split('.')[0][-4:]
+        if env in ['-stg', '-dev']:
+            host = 'https://auth-stg.revtel-api.com'
+        else:
+            host = 'https://auth.revtel-api.com'
+
         if version == 'v3':
-            url = f'https://{host}/{version}/certs'
+            url = f'{host}/{version}/certs'
             resp = requests.get(url).json()['keys']
             key = [key for key in resp if key['kid'] == kid][0]
         else:
@@ -68,18 +74,21 @@ class JWTVerifier(BaseVerifier):
         key = JWK.from_json(json.dumps(key))
         return key.export_to_pem()
 
+    def decode(self, token):
+        header = jwt.get_unverified_header(token)
+        unverified = jwt.decode(token, verify=False)
+        client = unverified['aud']
+        pub = self.get_public_key(header['kid'], unverified)
+        decoded = jwt.decode(token, algorithms='RS256', key=pub, verify=True, audience=client)
+        self.check_token_type(decoded['typ'])
+        return decoded
+
     def verify(self, token, **kwargs):
         try:
-            header = jwt.get_unverified_header(token)
-            unverified = jwt.decode(token, verify=False)
-            client = unverified['aud']
-            pub = self.get_public_key(header['kid'], unverified)
-            print(pub)
-            user = jwt.decode(token, algorithms='RS256', key=pub, verify=True, audience=client)
-            self.check_token_type(user['typ'])
+            user = self.decode(token)
             user = self.get_user_instance(user)
             self.check_user_permission(user)
-            client = self.client_class.get(id=client)
+            client = self.client_class.get(id=user['aud'])
             return client, user
         except Exception as e:
             raise exceptions.PermissionDenied(detail=str(e))
@@ -90,3 +99,15 @@ class RefreshVerifier(JWTVerifier):
 
     def get_user_instance(self, user):
         return user
+
+
+class CertVerifier(JWTVerifier):
+    token_type = 'certificate'
+
+    def verify(self, cert):
+        try:
+            decoded = self.decode(cert)
+            client = self.client_class.get(id=decoded['sub'])
+            return client, None
+        except Exception as e:
+            raise exceptions.PermissionDenied(detail=str(e))
